@@ -19,7 +19,7 @@ class Gem::Ext::Builder
     mf = File.read('Makefile')
     mf = mf.gsub(/^RUBYARCHDIR\s*=\s*\$[^$]*/, "RUBYARCHDIR = #{dest_path}")
     mf = mf.gsub(/^RUBYLIBDIR\s*=\s*\$[^$]*/, "RUBYLIBDIR = #{dest_path}")
-    mf = mf.gsub(/-o root -g bin/, "") if Gem::Installer.path_warning
+    mf = mf.gsub(/-o root -g bin/, "") unless Process.euid == 0
 
     File.open('Makefile', 'wb') {|f| f.print mf}
 
